==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-CO/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Ya existe una cuenta con este correo electrónico.',
    'account_not_found'      => 'El nombre de usuario o la contraseña son incorrectos.',
    'account_not_activated'  => 'Esta cuenta de usuario no está activada.',
    'account_suspended'      => 'Esta cuenta de usuario está suspendida.',
    'account_banned'         => 'Esta cuenta de usuario está bloqueada.',
    'throttle'               => 'Demasiados intentos fallidos de inicio de sesión. Por favor, inténtalo de nuevo en :minutes minutos.',

    'two_factor' => array(
        'already_enrolled'      => 'Su dispositivo ya está inscrito.',
        'success'               => 'Has iniciado sesión con éxito.',
        'code_required'         => 'El código de doble factor es necesario.',
        'invalid_code'          => 'El código de doble factor no es válido.',
    ),

    'signin' => array(
        'error'   => 'Hubo un problema al intentar iniciar sesión, por favor inténtelo de nuevo.',
        'success' => 'Has iniciado sesión con éxito.',
    ),

    'logout' => array(
        'error'   => 'Hubo un problema al intentar cerrar la sesión, por favor inténtelo de nuevo.',
        'success' => 'Has cerrado la sesión con éxito.',
    ),

    'signup' => array(
        'error'   => 'Hubo un problema al intentar crear tu cuenta. Por favor, inténtalo de nuevo.',
        'success' => 'Cuenta creada correctamente.',
    ),

    'forgot-password' => array(
        'error'   => 'Hubo un problema al intentar restablecer el código de contraseña, por favor inténtalo de nuevo.',
        'success' => 'Si esa dirección de correo electrónico existe en nuestro sistema, se ha enviado un correo electrónico de recuperación de contraseña.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Hubo un problema al intentar restablecer su contraseña, por favor inténtelo de nuevo.',
        'success' => 'Su contraseña se ha restablecido correctamente.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-CO/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Ya existe una cuenta con este correo electrónico.',
    'account_not_found'      => 'El nombre de usuario o la contraseña son incorrectos.',
    'account_not_activated'  => 'Esta cuenta de usuario no está activada.',
    'account_suspended'      => 'Esta cuenta de usuario está suspendida.',
    'account_banned'         => 'Esta cuenta de usuario está bloqueada.',
    'throttle'               => 'Demasiados intentos fallidos de inicio de sesión. Por favor, inténtalo de nuevo en :minutes minutos.',

    'two_factor' => array(
        'already_enrolled'      => 'Su dispositivo ya está inscrito.',
        'success'               => 'Ha iniciado sesión exitosamente.',
        'code_required'         => 'El código de doble factor es necesario.',
        'invalid_code'          => 'El código de doble factor no es válido.',
        'enter_two_factor_code' => 'Por favor ingrese su código de autenticación de dos factores.',
        'please_enroll'         => 'Por favor inscriba un dispositivo en la autenticación de dos factores.',
    ),

    'signin' => array(
        'error'   => 'Hubo un problema al intentar iniciar sesión, por favor inténtelo de nuevo.',
        'success' => 'Ha iniciado sesión exitosamente.',
    ),

    'logout' => array(
        'error'   => 'Hubo un problema al intentar cerrar la sesión, por favor inténtelo de nuevo.',
        'success' => 'Ha cerrado la sesión exitosamente.',
    ),

    'signup' => array(
        'error'   => 'Hubo un problema al intentar crear tu cuenta. Por favor, inténtalo de nuevo.',
        'success' => 'Cuenta creada correctamente.',
    ),

    'forgot-password' => array(
        'error'   => 'Hubo un problema al intentar restablecer el código de contraseña, por favor inténtalo de nuevo.',
        'success' => 'Si esa dirección de correo electrónico existe en nuestro sistema, se ha enviado un correo electrónico de recuperación de contraseña.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Hubo un problema al intentar restablecer su contraseña, por favor inténtelo de nuevo.',
        'success' => 'Su contraseña se ha restablecido correctamente.',
    ),


);
